@@ -1,6 +1,7 @@
 import sys
 import glob
-from assembler import assemble, ascii_binary_to_real_binary
+from assembler import (assemble, ascii_binary_to_real_binary,
+                       ascii_binary_to_vhdl_code)
 
 
 def main():
@@ -9,6 +10,7 @@ def main():
         print "USAGE: galapagos-as [-d] source.gas [source2.gas ...]"
         print "use --ascii to get output ascii strings of 0s and 1s" \
             "instead of real binary"
+        print "use --vhdl to generate fake VHDL ram for testing purposes"
         return
 
     debug = '-d' in sys.argv
@@ -39,6 +41,10 @@ def main():
         ascii_binary = ''.join(ascii_binary)
 
         ascii_mode = '--ascii' in sys.argv
+        vhdl_mode = '--vhdl' in sys.argv
+
+        if vhdl_mode:
+            ascii_binary_to_vhdl_code(ascii_binary)
 
         with open(path + '.out', 'w') as f:
             f.write(
