@@ -26,7 +26,7 @@ def assemble(lines):
         tokens, rest = line
         token_type, value = tokens[0]
         if token_type == 'operator':
-            if value == 'ld':
+            if value in ('ld', 'ldi', 'ldg'):
                 hot_register = tokens[1][1]
             else:
                 for token in tokens[1:]:
